@@ -1,20 +1,19 @@
+use 5.010000;
 use strict;
 use warnings;
+use utf8;
 
 package Regexp::Grammars::Common::String;
-BEGIN {
-  $Regexp::Grammars::Common::String::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Regexp::Grammars::Common::String::VERSION = '0.01000002';
-}
+
+our $VERSION = '1.000000';
 
 # ABSTRACT: Some basic String parsing Rules for Regexp::Grammars
 
-use Regexp::Grammars;
-use 5.010000;
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
-## no critic (RegularExpressions Documentation)
+use Regexp::Grammars;
+
+## no critic (RegularExpressions Documentation Variables::ProhibitUnusedVarsStricter)
 my $grammar = qr{
     <grammar: Regexp::Grammars::Common::String>
 
@@ -33,18 +32,78 @@ my $grammar = qr{
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Regexp::Grammars::Common::String - Some basic String parsing Rules for Regexp::Grammars
 
 =head1 VERSION
 
-version 0.01000002
+version 1.000000
 
 =head1 SYNOPSIS
 
@@ -69,9 +128,12 @@ version 0.01000002
 
 L<Regexp::Grammars|Regexp::Grammars> is just too useful to not use, but too pesky and confusing for new people.
 
-Some of the more complex things involve string extraction and escape-handling, and I seriously spent the better part 2 hours learning how to make this work. So, even if this module is not immediately useful, it may serve as an educational tool for others.
+Some of the more complex things involve string extraction and escape-handling, and I seriously spent the better part 2 hours
+learning how to make this work. So, even if this module is not immediately useful, it may serve as an educational tool for
+others.
 
-I probably should have delved deeper into the L<Regexp::Common|Regexp::Common> Family, but I couldn't find one in there that did exactly what I wanted.
+I probably should have delved deeper into the L<Regexp::Common|Regexp::Common> Family, but I couldn't find one in there that
+did exactly what I wanted.
 
 At present, this module only provides one rule, L</String>, but I will probably add a few more later.
 
@@ -103,10 +165,9 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
